AioIliad
===============================

[![Build Status](https://travis-ci.org/eliseomartelli/AioIliad.svg?branch=master)](https://travis-ci.org/eliseomartelli/AioIliad)

version number: 0.1.3
author: Eliseo Martelli

Overview
--------

A python package that can be installed with pip.

Installation / Usage
--------------------

To install use pip:

    $ pip install aioiliad


Or clone the repo:

    $ git clone https://github.com/eliseomartelli/aioiliad.git
    $ python setup.py install
    
Feel free to fork!
